@@ -1878,6 +1878,7 @@ ksba_cms_add_recipient (ksba_cms_t cms, ksba_cert_t cert)
 static gpg_error_t 
 ct_parse_data (ksba_cms_t cms)
 {
+  (void)cms;
   return gpg_error (GPG_ERR_NOT_IMPLEMENTED);
 }
 
@@ -2033,6 +2034,7 @@ ct_parse_enveloped_data (ksba_cms_t cms)
 static gpg_error_t 
 ct_parse_digested_data (ksba_cms_t cms)
 {
+  (void)cms;
   return gpg_error (GPG_ERR_NOT_IMPLEMENTED);
 }
 
@@ -2040,6 +2042,7 @@ ct_parse_digested_data (ksba_cms_t cms)
 static gpg_error_t 
 ct_parse_encrypted_data (ksba_cms_t cms)
 {
+  (void)cms;
   return gpg_error (GPG_ERR_NOT_IMPLEMENTED);
 }
 
@@ -2052,6 +2055,7 @@ ct_parse_encrypted_data (ksba_cms_t cms)
 static gpg_error_t 
 ct_build_data (ksba_cms_t cms)
 {
+  (void)cms;
   return gpg_error (GPG_ERR_NOT_IMPLEMENTED);
 }
 
@@ -3087,6 +3091,32 @@ build_enveloped_data_header (ksba_cms_t cms)
           err = gpg_error (GPG_ERR_ELEMENT_NOT_FOUND);
           goto leave;
         }
+
+      /* Now store NULL for the optional parameters.  From Peter
+       * Gutmann's X.509 style guide:
+       *
+       *   Another pitfall to be aware of is that algorithms which
+       *   have no parameters have this specified as a NULL value
+       *   rather than omitting the parameters field entirely.  The
+       *   reason for this is that when the 1988 syntax for
+       *   AlgorithmIdentifier was translated into the 1997 syntax,
+       *   the OPTIONAL associated with the AlgorithmIdentifier
+       *   parameters got lost.  Later it was recovered via a defect
+       *   report, but by then everyone thought that algorithm
+       *   parameters were mandatory.  Because of this the algorithm
+       *   parameters should be specified as NULL, regardless of what
+       *   you read elsewhere.
+       *
+       *        The trouble is that things *never* get better, they just
+       *        stay the same, only more so
+       *            -- Terry Pratchett, "Eric"
+       *
+       * Although this is about signing, we always do it.  Versions of
+       * Libksba before 1.0.6 had a bug writing out the NULL tag here,
+       * thus in reality we used to be correct according to the
+       * standards despite we didn't intended so.
+       */
+
       err = _ksba_der_store_null (n); 
       if (err)
         goto leave;
@@ -3263,6 +3293,7 @@ ct_build_enveloped_data (ksba_cms_t cms)
 static gpg_error_t 
 ct_build_digested_data (ksba_cms_t cms)
 {
+  (void)cms;
   return gpg_error (GPG_ERR_NOT_IMPLEMENTED);
 }
 
@@ -3270,6 +3301,7 @@ ct_build_digested_data (ksba_cms_t cms)
 static gpg_error_t 
 ct_build_encrypted_data (ksba_cms_t cms)
 {
+  (void)cms;
   return gpg_error (GPG_ERR_NOT_IMPLEMENTED);
 }
 
