@@ -40,37 +40,31 @@ static const struct {
               */
   const char *description;
   size_t      oidlen;
-  const unsigned char *oid;
+  const unsigned char *oid;  /* DER encoded OID.  */
+  const char *oidstr;        /* OID as dotted string.  */
 } oid_name_tbl[] = { 
-{"CN", 1, "CommonName",            3, "\x55\x04\x03"}, /* 2.5.4.3 */
-{"SN", 2, "Surname",               3, "\x55\x04\x04"}, /* 2.5.4.4 */
-{"SERIALNUMBER", 2, "SerialNumber",3, "\x55\x04\x05"}, /* 2.5.4.5 */
-{"C",  1, "CountryName",           3, "\x55\x04\x06"}, /* 2.5.4.6 */
-{"L" , 1, "LocalityName",          3, "\x55\x04\x07"}, /* 2.5.4.7 */
-{"ST", 1, "StateOrProvince",       3, "\x55\x04\x08"}, /* 2.5.4.8 */
-{"STREET", 1, "StreetAddress",     3, "\x55\x04\x09"}, /* 2.5.4.9 */
-{"O",  1, "OrganizationName",      3, "\x55\x04\x0a"}, /* 2.5.4.10 */
-{"OU", 1, "OrganizationalUnit",    3, "\x55\x04\x0b"}, /* 2.5.4.11 */
-{"T",  2, "Title",                 3, "\x55\x04\x0c"}, /* 2.5.4.12 */
-{"D",
-       3, "Description",           3, "\x55\x04\x0d"}, /* 2.5.4.13 */
-{"BC",
-       3, "BusinessCategory",      3, "\x55\x04\x0f"}, /* 2.5.4.15 */
-{"ADDR",
-       2, "PostalAddress",         3, "\x55\x04\x11"}, /* 2.5.4.16 */
-{"POSTALCODE" , 0, "PostalCode",   3, "\x55\x04\x11"}, /* 2.5.4.17 */
-{"GN", 2, "GivenName",             3, "\x55\x04\x2a"}, /* 2.5.4.42 */
-{"PSEUDO", 2, "Pseudonym",         3, "\x55\x04\x41"}, /* 2.5.4.65 */
+{"CN", 1, "CommonName",            3, "\x55\x04\x03", "2.5.4.3" },
+{"SN", 2, "Surname",               3, "\x55\x04\x04", "2.5.4.4" },
+{"SERIALNUMBER", 2, "SerialNumber",3, "\x55\x04\x05", "2.5.4.5" },
+{"C",  1, "CountryName",           3, "\x55\x04\x06", "2.5.4.6" },
+{"L" , 1, "LocalityName",          3, "\x55\x04\x07", "2.5.4.7" },
+{"ST", 1, "StateOrProvince",       3, "\x55\x04\x08", "2.5.4.8" },
+{"STREET", 1, "StreetAddress",     3, "\x55\x04\x09", "2.5.4.9" },
+{"O",  1, "OrganizationName",      3, "\x55\x04\x0a", "2.5.4.10" },
+{"OU", 1, "OrganizationalUnit",    3, "\x55\x04\x0b", "2.5.4.11" },
+{"T",  2, "Title",                 3, "\x55\x04\x0c", "2.5.4.12" },
+{"D",  3, "Description",           3, "\x55\x04\x0d", "2.5.4.13" },
+{"BC", 3, "BusinessCategory",      3, "\x55\x04\x0f", "2.5.4.15" },
+{"ADDR", 2, "PostalAddress",       3, "\x55\x04\x11", "2.5.4.16" },
+{"POSTALCODE" , 0, "PostalCode",   3, "\x55\x04\x11", "2.5.4.17" },
+{"GN", 2, "GivenName",             3, "\x55\x04\x2a", "2.5.4.42" },
+{"PSEUDO", 2, "Pseudonym",         3, "\x55\x04\x41", "2.5.4.65" },
 {"DC", 1, "domainComponent",      10, 
-       "\x09\x92\x26\x89\x93\xF2\x2C\x64\x01\x19"},
-                            /* 0.9.2342.19200300.100.1.25 */
+    "\x09\x92\x26\x89\x93\xF2\x2C\x64\x01\x19", "0.9.2342.19200300.100.1.25" },
 {"UID", 1, "userid",              10,
-       "\x09\x92\x26\x89\x93\xF2\x2C\x64\x01\x01"},
-                            /* 0.9.2342.19200300.100.1.1  */
-
-{"EMAIL", 3, "emailAddress",               9,
-       "\x2A\x86\x48\x86\xF7\x0D\x01\x09\x01" },  /* 1.2.840.113549.1.9.1 */
-
+    "\x09\x92\x26\x89\x93\xF2\x2C\x64\x01\x01", "0.9.2342.19200300.100.1.1 " },
+{"EMAIL", 3, "emailAddress",       9,
+    "\x2A\x86\x48\x86\xF7\x0D\x01\x09\x01",     "1.2.840.113549.1.9.1" },
 { NULL }
 };
 
@@ -555,13 +549,32 @@ append_atv (const unsigned char *image, AsnNode root, struct stringbuf *sb)
   if (name)
     put_stringbuf (sb, name);
   else
-    { /* No name in table: use the oid */
-      char *p = ksba_oid_to_str (image+node->off+node->nhdr, node->len);
+    { /* No name for the OID in the table; at least not DER encoded.
+         Now convert the OID to a string, try to find it in the table
+         again and use the string as last resort.  */
+      char *p;
+
+      p = ksba_oid_to_str (image+node->off+node->nhdr, node->len);
       if (!p)
         return gpg_error (GPG_ERR_ENOMEM);
-      put_stringbuf (sb, p);
+
+      for (i=0; *p && oid_name_tbl[i].name; i++)
+        {
+          if (oid_name_tbl[i].source == 1 
+              && !strcmp (p, oid_name_tbl[i].oidstr))
+            {
+              name = oid_name_tbl[i].name;
+              break;
+            }
+        }
+      if (name)
+        put_stringbuf (sb, name);
+      else
+        {
+          put_stringbuf (sb, p);
+          use_hex = 1;
+        }
       xfree (p);
-      use_hex = 1;
     }
   put_stringbuf (sb, "=");
   node = node->right;
@@ -971,7 +984,7 @@ parse_rdn (const unsigned char *string, const char **endp,
       for (i=0; oid_name_tbl[i].name; i++)
         {
           if ( n == strlen (oid_name_tbl[i].name)
-               && !memcmp (string, oid_name_tbl[i].name, n))
+               && !ascii_memcasecmp (string, oid_name_tbl[i].name, n))
             break;
         }
       if (!oid_name_tbl[i].name)
