@@ -24,6 +24,7 @@
 #include <errno.h>
 
 #include "../src/ksba.h"
+#define _KSBA_VISIBILITY_DEFAULT /*  */
 #include "../src/keyinfo.h"
 
 #include "oidtranstbl.h"
@@ -599,6 +600,12 @@ one_file (const char *fname)
           {
             ksba_sexp_t tmp;
 
+            if (verbose)
+              {
+                fputs ("  pubkey-DER: ", stdout);
+                print_hex (der, derlen);
+                putchar ('\n');
+              }
             err = _ksba_keyinfo_to_sexp (der, derlen, &tmp);
             if (err)
               {
